( cd usr/bin ; rm -rf xfsrestore )
( cd usr/bin ; ln -sf /usr/sbin/xfsrestore xfsrestore )
( cd usr/bin ; rm -rf xfsdump )
( cd usr/bin ; ln -sf /usr/sbin/xfsdump xfsdump )
( cd usr/man/man8 ; rm -rf xfs_info.8.gz )
( cd usr/man/man8 ; ln -sf xfs_growfs.8.gz xfs_info.8.gz )
( cd usr/man/man8 ; rm -rf xfsrq.8.gz )
( cd usr/man/man8 ; ln -sf xfsdq.8.gz xfsrq.8.gz )
